# AutoControl

AutoControl is a cross‑platform GUI automation framework that provides powerful and efficient features for mouse, keyboard, and image‑based automation.

## Features

* Powerful and practical GUI automation.
* Image recognition (template matching).
* Coordinate‑based operations.
* Mouse automation.
* Keyboard automation.
* Locate images.
* AutoControl scripting support.
* Generate JSON / HTML / XML reports.
* Remote automation support.
* Shell command integration.
* Screenshot support.
* OS‑independent design.
* Project & template management.

## ⚠️ Notice
Currently Unix/Linux Wayland GUI is not supported.
This may be added as a future feature.

## Installation

```
# make sure you have install cmake libssl-dev (on linux)
pip install je_auto_control
```

##  Requirements

* Python 3.9 or later
* pip 19.3 or later



## Development Environment
* Windows 11
* macOS 11 Big Sur
* Ubuntu 20.04

## Tested On
* Windows 10 ~ 11
* macOS 10.15 ~ 11 Big Sur
* Ubuntu 20.04
* Raspberry Pi 3B / 4B

## Setting Up Development Environment
```commandline
pip install -r dev_requirements.txt
```



